declare module "wix-pro-gallery-backend" {
    interface Gallery {
        /**
         * Gallery ID.
         * @readonly
         */
        _id?: string | null;
        /** Gallery name. */
        name?: string | null;
        /**
         * Total number of items in the gallery.
         * @readonly
         */
        totalItems?: number | null;
        /** Media items in the gallery. */
        items?: Item[];
        /**
         * Gallery sort order.
         * Determines which position a gallery is displayed on the site. <br />
         *
         * Min: `1` <br />
         */
        sortOrder?: number | null;
        /**
         * Date and time the gallery was created.
         * @readonly
         */
        _createdDate?: Date;
    }
    interface Item extends ItemMetadataOneOf {
        /**
         * Item ID.
         * @readonly
         */
        _id?: string | null;
        /**
         * Item sort order.
         * Determines which position a media item is displayed in the gallery. <br />
         *
         * Min: `1` <br />
         * Default: [Epoch](https://www.epoch101.com/) timestamp in descending order (end of the gallery items list). <br />
         *
         * *Note:** If the same sort order number is assigned to more than one media item in a gallery, the first media item to which it was assigned will come first.
         */
        sortOrder?: number | null;
        /** Item title. */
        title?: string | null;
        /** Item description. */
        description?: string | null;
        /** Link from the item. You can link to Wix sites or external URLs. */
        link?: Link;
        /**
         * Item data type. One of: <br /> +"IMAGE" <br /> +"VIDEO" <br /> +"TEXT"
         * @readonly */
        type?: Type;
        /**
         * Date and time the item was created.
         * @readonly
         */
        _createdDate?: Date;
        /**
         * Date and time the item was last updated.
         * @readonly
         */
        _updatedDate?: Date;
        /** Item tags. */
        tags?: Tags;
        /**
         * item's secondary media (image or text media revealed on hover)
         * @internal
         */
        secondaryMedia?: SecondaryMedia;
        /** Details about the image. */
        image?: Image;
        /** Details about the video. */
        video?: Video;
        /** Details about the text file. */
        text?: Text;
    }
    /** @oneof */
    interface ItemMetadataOneOf {
        /** Details about the image. */
        image?: Image;
        /** Details about the video. */
        video?: Video;
        /** Details about the text file. */
        text?: Text;
    }
    interface Link {
        /**
         * Link type.
         * @internal
         */
        type?: LinkType;
        /** Display text of the link. */
        text?: string | null;
        /** Target URL of the link. */
        url?: string | null;
        /**
         * Whether the link opens in a new tab or window. One of:
         * + `_blank`: The link opens in a new tab or window.
         * + `_self`: The link opens in the same tab or window.
         */
        target?: string | null;
        /**
         * Information about the link. Reserved for internal use.
         * @internal
         */
        wixLinkData?: WixLink;
    }
    enum LinkType {
        UNDEFINED = "UNDEFINED",
        /** external link */
        EXTERNAL = "EXTERNAL",
        /** for internal usage using wixLinkData */
        INTERNAL = "INTERNAL"
    }
    /** The link object generated by panels in the editor and used by applications in Wix */
    interface WixLink extends WixLinkLinkOneOf {
        /** External link type */
        external?: ExternalLink;
        /** Page link type */
        page?: PageLink;
        /** Anchor link type */
        anchor?: AnchorLink;
        /** Dynamic page link type */
        dynamicPage?: DynamicPageLink;
        /** Document link type */
        document?: DocumentLink;
        /** Email link type */
        email?: EmailLink;
        /** Phone link type */
        phone?: PhoneLink;
        /** Address link type */
        address?: AddressLink;
        /** WhatsApp link type */
        whatsApp?: WhatsAppLink;
    }
    /** @oneof */
    interface WixLinkLinkOneOf {
        /** External link type */
        external?: ExternalLink;
        /** Page link type */
        page?: PageLink;
        /** Anchor link type */
        anchor?: AnchorLink;
        /** Dynamic page link type */
        dynamicPage?: DynamicPageLink;
        /** Document link type */
        document?: DocumentLink;
        /** Email link type */
        email?: EmailLink;
        /** Phone link type */
        phone?: PhoneLink;
        /** Address link type */
        address?: AddressLink;
        /** WhatsApp link type */
        whatsApp?: WhatsAppLink;
    }
    interface ExternalLink {
        /** The url of the page */
        url?: string;
        /** Where this link should open, supports _self and _blank or any name the user chooses. _self means same page, _blank means new page. */
        target?: string | null;
    }
    interface PageLink {
        /** The page id we want from the site */
        pageId?: string;
        /** Where this link should open, supports _self and _blank or any name the user chooses. _self means same page, _blank means new page. */
        target?: string | null;
    }
    interface AnchorLink {
        /** The name of the anchor */
        anchorName?: string;
        /** The data id (from the JSON page) of the anchor that should be used */
        anchorDataId?: string;
        /** The page id we want from the site */
        pageId?: string;
    }
    interface DynamicPageLink {
        /** The router that handles this link */
        routerId?: string;
        /** The path data we'd like */
        innerRoute?: string;
        /** The data id (from the JSON page) of the anchor that should be used */
        anchorDataId?: string | null;
    }
    interface DocumentLink {
        /** The id of the document */
        docId?: string;
        /** The name of the document for download purposes */
        name?: string | null;
        /** If this document can be indexed by scrapers, default is false */
        indexable?: boolean;
    }
    interface EmailLink {
        /** The email we will be sending a message to */
        recipient?: string;
        /** The subject of the email */
        subject?: string | null;
        /** The body of the email */
        body?: string | null;
    }
    interface PhoneLink {
        /** The phone number we want to link to */
        phoneNumber?: string;
    }
    interface AddressLink {
        /** An address that we can link to */
        address?: string;
    }
    interface WhatsAppLink {
        /** The whatsApp phone number we want to connect with */
        phoneNumber?: string;
    }
    enum Type {
        UNDEFINED = "UNDEFINED",
        IMAGE = "IMAGE",
        VIDEO = "VIDEO",
        TEXT = "TEXT"
    }
    interface Image {
        /** @internal */
        type?: ImageType;
        /** The image's Wix media URL in the following format: `'wix:image://v1/<uri>/<filename>#originWidth=<width>&originHeight=<height>[&watermark=<watermark_manifest_string>]'`. */
        imageInfo?: string;
        /** Focal point of the image. */
        focalPoint?: Point;
        /** Set of key-value pairs describing the media in [Exchangeable Image File format](https://en.wikipedia.org/wiki/Exif). */
        exif?: Record<string, any> | null;
        /**
         * Image compression level. <br />
         *
         * Min: `30` <br />
         * Max: `100`
         */
        quality?: number | null;
        /** [Unsharp masking](https://en.wikipedia.org/wiki/Unsharp_masking) values of the image. */
        unsharpMasking?: UnsharpMasking;
        /**
         * Whether the image is saved in secure media.
         * @internal
         */
        secure?: boolean | null;
        /**
         * When image is saved in secure media, token is generated.
         * @internal
         * @readonly
         */
        token?: string | null;
    }
    enum ImageType {
        UNDEFINED = "UNDEFINED",
        WIX_MEDIA = "WIX_MEDIA",
        EXTERNAL = "EXTERNAL"
    }
    interface Point {
        /** X-coordinate of the focal point. */
        x?: number;
        /** Y-coordinate of the focal point. */
        y?: number;
    }
    interface UnsharpMasking {
        /**
         * Unsharp masking amount. Controls the sharpening strength. <br />
         *
         * Min: `0` <br />
         * Max: `5`
         */
        amount?: number | null;
        /** Unsharp masking radius in pixels. Controls the sharpening width. */
        radius?: number | null;
        /**
         * Unsharp masking threshold. Controls how different neighboring pixels must be for shapening to apply. <br />
         *
         * Min: `0` <br />
         * Max: `1`
         */
        threshold?: number | null;
    }
    interface Video {
        type?: VideoType;
        /** Information for a Wix Media video or for a video from an external source (YouTube or Vimeo). */
        videoInfo?: string;
        /**
         * Video duration in milliseconds - deprecated.
         * @internal
         */
        duration?: string | null;
        /** Manually defined video duration in milliseconds. */
        durationInMillis?: number | null;
    }
    enum VideoType {
        UNDEFINED = "UNDEFINED",
        WIX_MEDIA = "WIX_MEDIA",
        YOUTUBE = "YOUTUBE",
        VIMEO = "VIMEO"
    }
    interface Text {
        /** Text in HTML format. */
        html?: string | null;
        /**
         * Set of key-value pairs describing the [CSS style](https://en.wikipedia.org/wiki/CSS) of the text.
         *
         * __Note:__ The object structure is customizable. See the [List Gallery Items](https://dev.wix.com/api/rest/site-content/pro-gallery/list-gallery-items) code example for supported values.
         */
        css?: Record<string, any> | null;
        /** Reserved for internal use. */
        editorHtml?: string | null;
        /** Reserved for internal use. */
        editorFontId?: string | null;
    }
    interface Tags {
        /** List of tags assigned to the media item. */
        values?: string[];
    }
    interface SecondaryMedia extends SecondaryMediaMetadataOneOf {
        /** secondary media photo metadata (optional) */
        image?: Image;
        /** secondary media text metadata (optional) */
        text?: Text;
    }
    /** @oneof */
    interface SecondaryMediaMetadataOneOf {
        /** secondary media photo metadata (optional) */
        image?: Image;
        /** secondary media text metadata (optional) */
        text?: Text;
    }
    enum State {
        UNDEFINED = "UNDEFINED",
        /** The gallery in the Editor segment */
        SAVED = "SAVED",
        /** The gallery in the LiveSite segment */
        PUBLISHED = "PUBLISHED"
    }
    interface ListGalleriesResponse {
        /** Total number of galleries in the site. */
        totalGalleries?: number | null;
        /** List of galleries. Sorted by `_createdDate`. */
        galleries?: Gallery[];
    }
    interface ListGalleryItemsResponse {
        /** List of media items in the gallery. */
        items?: Item[];
    }
    interface DeleteGalleryResponse {
        /**
         * ID of the deleted gallery.
         * @readonly
         */
        galleryId?: string;
    }
    interface DeleteGalleryItemsResponse {
        /** Gallery that previously included the deleted media item. */
        gallery?: Gallery;
    }
    interface DeleteGalleryItemResponse {
        /**
         * ID of the deleted media item.
         * @readonly
         */
        itemId?: string;
    }
    interface PublishGalleryResponse {
        /** Published gallery. */
        gallery?: Gallery;
    }
    interface ListGalleriesOptions {
        /** Number of galleries to list. Defaults to 10. */
        itemLimit?: number | null;
        /** Number of galleries to skip in the returns. Defaults to 0. */
        offset?: number | null;
        /** Number of galleries to list. Defaults to 10. */
        limit?: number | null;
        /**
         * Fields to include in the response object. Setting the `fields` option filters the response object so that it only contains the specified fields.
         * @internal
         */
        fields?: string[];
        /**
         * State of the galleries.
         * @internal
         */
        state?: State;
    }
    interface GetGalleryOptions {
        /** Number of media items to skip in the returns. Defaults to 0. */
        itemOffset?: number | null;
        /**
         * Maximum number of media items to return. <br />
         *
         * Min: `1` <br />
         * Max: `100` <br />
         * Default: `50`
         */
        itemLimit?: number | null;
        /**
         * State of the retrieved galleries.
         * @internal
         */
        state?: State;
        /**
         * This allows us to fallback to legacy galleries until they are fully migrated. If this is not provided and a fallback is necessary, the process will fail
         * External reference. **Note:** This property is not validated by Wix.
         * @internal
         */
        externalId?: string | null;
        /** @internal */
        htmlSiteRevision?: string | null;
    }
    interface ListGalleryItemsOptions {
        /** Number of media items to skip in the returns. Defaults to 0. */
        itemOffset?: number | null;
        /**
         * Maximum number of media items to return. <br />
         *
         * Min: `1` <br />
         * Max: `100` <br />
         * Default: `50`
         */
        itemLimit?: number | null;
        /**
         * State of the retrieved gallery.
         * @internal
         */
        state?: State;
    }
    interface GetGalleryItemIdentifiers {
        /** Gallery ID. */
        galleryId: string;
        /** Item ID. */
        itemId: string;
    }
    interface GetGalleryItemOptions {
        /**
         * State of the gallery.
         * @internal
         */
        state?: State;
    }
    interface CreateGalleryOptions {
        /** Gallery to create. */
        gallery?: Gallery;
        /**
         * State of the gallery to create.
         * @internal
         */
        state?: State;
        /** Gallery ID to clone from. */
        cloneFromGalleryId?: string | null;
    }
    interface UpdateGallery {
        /**
         * Gallery ID.
         * @readonly
         */
        _id?: string | null;
        /** Gallery name. */
        name?: string | null;
        /**
         * Total number of items in the gallery.
         * @readonly
         */
        totalItems?: number | null;
        /** Media items in the gallery. */
        items?: Item[];
        /**
         * Gallery sort order.
         * Determines which position a gallery is displayed on the site. <br />
         *
         * Min: `1` <br />
         */
        sortOrder?: number | null;
        /**
         * Date and time the gallery was created.
         * @readonly
         */
        _createdDate?: Date;
    }
    interface UpdateGalleryOptions {
        /**
         * State of the gallery to update.
         * @internal
         */
        state?: State;
    }
    interface DeleteGalleryOptions {
        /**
         * State of the gallery to delete.
         * @internal
         */
        state?: State;
    }
    interface DeleteGalleryItemsOptions {
        /** ID of the media item to delete. */
        itemsIds?: string[];
        /**
         * State of the gallery.
         * @internal
         */
        state?: State;
    }
    interface CreateGalleryItemOptions {
        /**
         * Gallery state.
         * @internal
         */
        state?: State;
    }
    interface UpdateGalleryItemIdentifiers {
        /** ID of the gallery containing the item to update.  */
        galleryId: string;
        /**
         * ID of the item to update.
         * @readonly
         */
        itemId?: string | null;
    }
    interface UpdateGalleryItem {
        /**
         * Item ID.
         * @readonly
         */
        _id?: string | null;
        /**
         * Item sort order.
         * Determines which position a media item is displayed in the gallery. <br />
         *
         * Min: `1` <br />
         * Default: [Epoch](https://www.epoch101.com/) timestamp in descending order (end of the gallery items list). <br />
         *
         * *Note:** If the same sort order number is assigned to more than one media item in a gallery, the first media item to which it was assigned will come first.
         */
        sortOrder?: number | null;
        /** Item title. */
        title?: string | null;
        /** Item description. */
        description?: string | null;
        /** Link from the item. You can link to Wix sites or external URLs. */
        link?: Link;
        /**
         * Item data type. One of: <br /> +"IMAGE" <br /> +"VIDEO" <br /> +"TEXT"
         * @readonly
         */
        type?: Type;
        /**
         * Date and time the item was created.
         * @readonly
         */
        _createdDate?: Date;
        /**
         * Date and time the item was last updated.
         * @readonly
         */
        _updatedDate?: Date;
        /** Item tags. */
        tags?: Tags;
        /**
         * item's secondary media (image or text media revealed on hover)
         * @internal
         */
        secondaryMedia?: SecondaryMedia;
        /** Details about the image. */
        image?: Image;
        /** Details about the video. */
        video?: Video;
        /** Details about the text file. */
        text?: Text;
    }
    interface UpdateGalleryItemOptions {
        /**
         * Gallery state.
         * @internal
         */
        state?: State;
    }
    interface DeleteGalleryItemIdentifiers {
        /** Gallery ID. */
        galleryId: string;
        /** ID of the media item to delete. */
        itemId: string;
    }
    interface DeleteGalleryItemOptions {
        /**
         * Gallery state.
         * @internal
         */
        state?: State;
    }
    function listGalleries(options?: ListGalleriesOptions): Promise<ListGalleriesResponse>;
    function getGallery(galleryId: string, options?: GetGalleryOptions): Promise<Gallery>;
    function listGalleryItems(galleryId: string, options?: ListGalleryItemsOptions): Promise<ListGalleryItemsResponse>;
    function getGalleryItem(identifiers: GetGalleryItemIdentifiers, options?: GetGalleryItemOptions): Promise<Item>;
    function createGallery(options?: CreateGalleryOptions): Promise<Gallery>;
    function updateGallery(_id: string | null, gallery: UpdateGallery, options?: UpdateGalleryOptions): Promise<Gallery>;
    function deleteGallery(galleryId: string, options?: DeleteGalleryOptions): Promise<DeleteGalleryResponse>;
    function deleteGalleryItems(galleryId: string, options?: DeleteGalleryItemsOptions): Promise<DeleteGalleryItemsResponse>;
    function createGalleryItem(galleryId: string, item: Item, options?: CreateGalleryItemOptions): Promise<Item>;
    function updateGalleryItem(identifiers: UpdateGalleryItemIdentifiers, item: UpdateGalleryItem, options?: UpdateGalleryItemOptions): Promise<Item>;
    function deleteGalleryItem(identifiers: DeleteGalleryItemIdentifiers, options?: DeleteGalleryItemOptions): Promise<DeleteGalleryItemResponse>;
    function publishGallery(galleryId: string): Promise<PublishGalleryResponse>;
    const proGalleryV2Gallery_backend_d_listGalleries: typeof listGalleries;
    const proGalleryV2Gallery_backend_d_getGallery: typeof getGallery;
    const proGalleryV2Gallery_backend_d_listGalleryItems: typeof listGalleryItems;
    const proGalleryV2Gallery_backend_d_getGalleryItem: typeof getGalleryItem;
    const proGalleryV2Gallery_backend_d_createGallery: typeof createGallery;
    const proGalleryV2Gallery_backend_d_updateGallery: typeof updateGallery;
    const proGalleryV2Gallery_backend_d_deleteGallery: typeof deleteGallery;
    const proGalleryV2Gallery_backend_d_deleteGalleryItems: typeof deleteGalleryItems;
    const proGalleryV2Gallery_backend_d_createGalleryItem: typeof createGalleryItem;
    const proGalleryV2Gallery_backend_d_updateGalleryItem: typeof updateGalleryItem;
    const proGalleryV2Gallery_backend_d_deleteGalleryItem: typeof deleteGalleryItem;
    const proGalleryV2Gallery_backend_d_publishGallery: typeof publishGallery;
    namespace proGalleryV2Gallery_backend_d {
        export { proGalleryV2Gallery_backend_d_listGalleries as listGalleries, proGalleryV2Gallery_backend_d_getGallery as getGallery, proGalleryV2Gallery_backend_d_listGalleryItems as listGalleryItems, proGalleryV2Gallery_backend_d_getGalleryItem as getGalleryItem, proGalleryV2Gallery_backend_d_createGallery as createGallery, proGalleryV2Gallery_backend_d_updateGallery as updateGallery, proGalleryV2Gallery_backend_d_deleteGallery as deleteGallery, proGalleryV2Gallery_backend_d_deleteGalleryItems as deleteGalleryItems, proGalleryV2Gallery_backend_d_createGalleryItem as createGalleryItem, proGalleryV2Gallery_backend_d_updateGalleryItem as updateGalleryItem, proGalleryV2Gallery_backend_d_deleteGalleryItem as deleteGalleryItem, proGalleryV2Gallery_backend_d_publishGallery as publishGallery, };
    }
    export { proGalleryV2Gallery_backend_d as proGallery };
}
